@@ -254,6 +254,8 @@ class pftree(object):
         if len(self.args):
             kwargs  = {**self.args, **kwargs}
 
+        for pkey in ['du', 'duf']:
+            if pkey not in self.args.keys(): self.args[pkey] = False
         if self.args['du']:
             self.verbosityLevel = 2
             self.debugLevel     = 2
@@ -801,14 +803,7 @@ class pftree(object):
             nonlocal    d_tree
             nonlocal    fn_inputReadCallback
 
-            # self.simpleProgress_show(index, total, '%s:%s' %
-            #     ('%25s' %threading.currentThread().getName(),
-            #      '%25s' % fn_inputReadCallback.__name__)
-            # )
-
-            d_read = fn_inputReadCallback(
-                ('%s/%s' % (self.str_inputDir, path), data), **kwargs
-            )
+            d_read = fn_inputReadCallback((path, data), **kwargs)
 
             if 'status' in d_read.keys():
                 d_tree[path]    = d_read
@@ -828,14 +823,7 @@ class pftree(object):
             nonlocal    d_tree
             nonlocal    fn_analysisCallback
 
-            # self.simpleProgress_show(index, total, '%s:%s' %
-            #     ('%25s' % threading.currentThread().getName(),
-            #      '%25s' % fn_analysisCallback.__name__)
-            # )
-
-            d_analysis          = fn_analysisCallback(
-                ('%s/%s' % (self.str_inputDir, path), d_tree[path]), **kwargs
-            )
+            d_analysis          = fn_analysisCallback((path, d_tree[path]), **kwargs)
 
             if 'status' in d_analysis.keys():
                 if d_analysis['status']:
@@ -977,7 +965,13 @@ class pftree(object):
             b_inputStatusHist:      bool = False
             b_outputStatusHist:     bool = False
 
-            for path, data in tqdm(self.d_inputTree.items(), desc = str_desc):
+            if int(self.verbosityLevel) and self.toConsole():
+                iterator        = tqdm( self.d_inputTree.items(),
+                                    desc = ' Analyzing    tree')
+            else:
+                iterator        = self.d_inputTree.items()
+
+            for path, data in iterator:
                 dret_inputSet   = {}
                 dret_analyze    = {}
                 dret_outputSet  = {}
@@ -1066,11 +1060,16 @@ class pftree(object):
                                         threadRem,
                                         alreadyRunCount)
 
+            if int(self.verbosityLevel) and self.toConsole():
+                iterator        = tqdm( self.d_inputTree.items(),
+                                    desc = str_desc)
+            else:
+                iterator        = self.d_inputTree.items()
+
             # Read
             if fn_inputReadCallback:
                 index = 1
-                for path, data in tqdm( self.d_inputTree.items(),
-                                        desc = ' Reading      tree'):
+                for path, data in iterator:
                     dret_inputSet   = inputSet_read(path, data)
                     # filesRead       += dret_inputSet['filesRead']
                     index += 1
@@ -1079,8 +1078,7 @@ class pftree(object):
             if fn_analysisCallback:
                 index               = 1
                 l_threadAnalysis    = []
-                for path, data in tqdm( self.d_inputTree.items(),
-                                        desc = ' Analyzing    tree'):
+                for path, data in iterator:
                     l_threadAnalysis.append(thread_createOnFunction(
                                                     path, data,
                                                     'analysisThread',
@@ -1096,8 +1094,7 @@ class pftree(object):
             # Write
             if fn_outputWriteCallback:
                 index   = 1
-                for path, data in tqdm( self.d_inputTree.items(),
-                                        ' Saving  new  tree'):
+                for path, data in iterator:
                     dret_outputSet  = outputSet_write(path, d_tree[path])
                     # filesSaved      += dret_outputSet['filesSaved']
                     index += 1
